Array

Struct Array 

pub struct Array<Identifier = String, Var = VarRef<Identifier>> {
    pub identifier: Identifier,
    pub note: Option<String>,
    pub size: Vec<usize>,
    pub domains: Vec<(Vec<Var>, RangeList<IntVal>)>,
}
Definition of a k-dimensional arrays of variables

Fields

identifier: Identifier

Name used to refer to the array

note: Option<String>

Comment by the user

size: Vec<usize>

Dimensions of the array

domains: Vec<(Vec<Var>, RangeList<IntVal>)>

Domains of the variables contained within the array

Note that when several subsets of variables of an array have different domains, a rangelist is provided for each of these subsets. The first member of the tuple indicates the list of variables to which the domain definition applies. The special identifier others is used to declare a default domain for all other variables contained in the array.

Implementations

Source

impl<Identifier: Clone + Hash + Eq + ToString> Array<Identifier, VarRef<Identifier>>

pub fn unroll( &self, ) -> Result<Array<Identifier, SimpleRef<Identifier>>, UnrollError>

Expand the domain definitions of the array domain defintiions into SimpleRef.